@@ -9,7 +9,7 @@ Visit <https://github.com/jwodder/linesep> or <https://linesep.rtfd.io> for
 more information.
 """
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 __author__ = "John Thorvald Wodder II"
 __author_email__ = "linesep@varonathe.org"
 __license__ = "MIT"
@@ -33,6 +33,7 @@ from .funcs import (
     write_terminated,
 )
 from .splitters import (
+    ParagraphSplitter,
     PrecededSplitter,
     SeparatedSplitter,
     Splitter,
@@ -40,11 +41,13 @@ from .splitters import (
     SplitterEmptyError,
     SplitterState,
     TerminatedSplitter,
+    UnicodeNewlineSplitter,
     UniversalNewlineSplitter,
     get_newline_splitter,
 )
 
 __all__ = [
+    "ParagraphSplitter",
     "PrecededSplitter",
     "SeparatedSplitter",
     "Splitter",
@@ -52,6 +55,7 @@ __all__ = [
     "SplitterEmptyError",
     "SplitterState",
     "TerminatedSplitter",
+    "UnicodeNewlineSplitter",
     "UniversalNewlineSplitter",
     "ascii_splitlines",
     "get_newline_splitter",
